@@ -16,3 +16,7 @@ def test_useragent():
     assert "devpi-hello/1.2" in ua
     assert sys.version.split()[0] in ua
     assert "*" not in ua
+
+def test_exception_attributes():
+    session = new_requests_session()
+    assert isinstance(session.Errors, tuple)
